@@ -4,9 +4,12 @@ from plone.app.kss.plonekssview import PloneKSSView
 from Products.Five.browser import BrowserView
 from viewlets import Bookings as BookingsViewlet
 from viewlets import BookingForm as BookingFormViewlet
+from DateTime import DateTime
 
 
-def create_booking(context, title='Booking', hours=0, minutes=0):
+def create_booking(context, title='Booking', hours=0, minutes=0,
+                   description=u'',
+                   day=None):
     """Create a booking.
 
     We introduce a Mock Booking class for testing.
@@ -91,12 +94,38 @@ def create_booking(context, title='Booking', hours=0, minutes=0):
     >>> booking.minutes
     15
 
+    By default the description is empty, but optionally we can supply
+    one.
+
+    >>> booking.description
+    u''
+    >>> create_booking(context, title='Title', description=u'A description.')
+    >>> booking = context.items[-1]
+    >>> booking.description
+    u'A description.'
+
+    We can supply a day on which to book. The default is today. Note that
+    below checks will fail when executed at exactly midnight... ;-)
+
+    >>> today = str(DateTime())[:10]
+    >>> str(booking.bookingDate)[:10] == today
+    True
+    >>> create_booking(context, title='Title', day=DateTime('1972-12-25'))
+    >>> booking = context.items[-1]
+    >>> booking.bookingDate
+    DateTime('1972/12/25')
+
     """
+
+    if day == None:
+        day = DateTime()
     idx = 1
     while str(idx) in context.objectIds():
         idx = idx + 1
     context.invokeFactory('Booking', id=str(idx), title=title,
-                          hours=hours, minutes=minutes)
+                          hours=hours, minutes=minutes,
+                          description=description,
+                          bookingDate=day)
 
 
 class Create(BrowserView):
